# vcfempy

This is a package implementing the Voronoi Cell Finite Element Method (VCFEM) for analysis of problems in geomechanics.

For information contact [Brandon Karchewski](mailto:brandon.karchewski@ucalgary.ca).